Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2518)

Unified Diff: compiler/java/com/google/dart/compiler/CommandLineOptions.java

Issue 10837282: Issue 4518. Use inferred types to check if type of argumetn is assignable to the type of parameter (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: compiler/java/com/google/dart/compiler/CommandLineOptions.java
diff --git a/compiler/java/com/google/dart/compiler/CommandLineOptions.java b/compiler/java/com/google/dart/compiler/CommandLineOptions.java
index 517d36db6c32f4681210b084897aa9e0979550e7..c7eeca505026fd244bc4395c5282e4dc0c8e4285 100644
--- a/compiler/java/com/google/dart/compiler/CommandLineOptions.java
+++ b/compiler/java/com/google/dart/compiler/CommandLineOptions.java
@@ -162,10 +162,10 @@ public class CommandLineOptions {
}
/**
* Returns whether "not a member" warnings should be reported for inferred types.
*/
- public boolean memberWarningForInferredTypes() {
- return true;
+ public boolean typeChecksForInferredTypes() {
+ return false;
}
/**
@@ -162,10 +162,10 @@ public class CommandLineOptions {
}
/**
- * Returns whether "not a member" warnings should be reported for inferred types.
+ * Returns whether inferred types should be used for type checks.
*/

Powered by Google App Engine
This is Rietveld 408576698